﻿using System.Collections.Generic;
using System.IO;

using Dundas.BI.Web.Extensibility.Parameters;

namespace MyCompany.Sample.SampleControl
{
    /// <summary>
    /// This class represents a stickynote adapter.
    /// </summary>
    public class StickyNoteAdapterInfo : AdapterInfo
	{
		#region Constructors

		/// <summary>
		/// Initializes a new instance of the <see cref="StickyNoteAdapterInfo"/> class.
		/// </summary>
		public StickyNoteAdapterInfo()
		{
			this.FullJavaScriptName = "mycompany.controls.sample.stickynote.Info";
		}

		#endregion Constructors

        #region Private Methods

        /// <summary>
        /// Gets the resource as string from current assembly.
        /// </summary>
        /// <param name="name">The full path to the resource.</param>
        /// <returns>The resource as <see cref="T:System.string" />.</returns>
        private string GetResourceFromCurrentAssembly(string name)
        {
	        System.Reflection.Assembly currentAssembly =
		        typeof(StickyNoteAdapterInfo).Assembly;

	        using (StreamReader streamReader =
		        new StreamReader(currentAssembly.GetManifestResourceStream(name)))
	        {

		        return
			        streamReader.ReadToEnd();

	        }
        }

        #endregion Private Methods

        #region Public Methods

        /// <summary>
        /// Gets all the JavaScript resources as <see cref="T:System.string" />s for this info. 
        /// The order they are returned should be the ordered they need to be included in.
        /// </summary>
        /// <returns>
        /// The JavaScript resources as <see cref="T:System.string" />s. This might be null.
        /// </returns>
        public override IList<string> GetResources()
        {
	        return new List<string>
	        {
		        GetResourceFromCurrentAssembly("MyCompany.Sample.SampleControl.mycompany.controls.sample.stickynote.info.js"),
		        GetResourceFromCurrentAssembly("MyCompany.Sample.SampleControl.mycompany.controls.sample.stickynote.adapter.js")

	        };
        }

        /// <summary>
        /// Gets all the CSS resources (as strings) for this info. 
        /// The order they are returned should be the ordered they need to be included in.
        /// </summary>
        /// <returns>The CSS resources (as strings). This might be null.</returns>
        public override IList<string> GetCssResources()
        {
            return
                new List<string>
                {
                    GetResourceFromCurrentAssembly("MyCompany.Sample.SampleControl.mycompany.controls.sample.stickynote.css")
                };
        }

        #endregion Public Methods
    }
}