﻿"use strict";

(function ($) {



    var Utility = {
        parseItem: function (item) {
            return Class.fromJSON(JSON.stringify(item || {}));
        },
        parseItems: function (items) {
            return $.map(items || [], function (item, index) {
                return Utility.parseItem(item);
            });
        }
    };

    var Constants = {

        // Label.
        StickyNoteContainerCssClass: 'stickyNoteContainer',
        StickyNoteControlCssClass: 'stickyNoteControl',
        StickyNoteControlLabelCssClass: 'stickyNoteLabel'

    };

    mycompany.controls.sample.stickynote.Adapter = dundas.view.controls.Adapter.extend({

        init: function (adapterOptions) {
            /// <summary>
            /// Initializes the Adapter. Called during construction.
            /// </summary>
            /// <param name="adapterOptions" type="Object" optional="true">(optional) An object literal parameter specifying default values.</param>

            // Call base.
            this._super(adapterOptions);
        },

        onLoaded: function () {
            /// <summary>
            /// Called when the adapter is loaded and setup.
            /// The control should be setup by the adapter now and added to the DOM (container property).
            /// Implementers of this method must call this._super() at the end if they want actions
            /// and events to be automatically setup.
            /// </summary>

            // Setup my UI control here.
            if (this.control == null) {
                this._createControl();
            }

            this._super();

            this._stickyNoteContainer.click(function () {
                $(this).fadeOut( "fast" );
            });
        },

        _createControl: function() {
            // Control.

            this._stickyNoteContainer =
                $(document.createElement("div"))
                .addClass(Constants.StickyNoteContainerCssClass)
                .appendTo($(this.container));

            this.control = $(document.createElement("div"))
                .addClass(Constants.StickyNoteControlCssClass)
                .appendTo(this._stickyNoteContainer);

            // Label.
            this._label = $(document.createElement("div"))
                .addClass(Constants.StickyNoteControlLabelCssClass)
                .appendTo(this.control);

            // Set default font family and size
            this.fontFamily = "'Reenie Beanie'";
            this.fontSize = "36px";

            // Set defaults properties for the controls.
            this.stickynoteText = "Lorem ipsum dolor sit amet, consectetur adipiscing elit.";

            var randomAngle = Math.floor((Math.random() * 4));
            randomAngle = (Math.random() < 0.5) ? -randomAngle : randomAngle;

            this.angle = randomAngle;

            var randomColorIndex = Math.floor((Math.random() * 3));

            switch (randomColorIndex) {
                case 0:
                    this.background = new dundas.controls.SolidColorBrush(dundas.controls.Color.fromString("#ffc"));
                    break;
                case 1:
                    this.background = new dundas.controls.SolidColorBrush(dundas.controls.Color.fromString("#cfc"));
                    break;
                case 2:
                    this.background = new dundas.controls.SolidColorBrush(dundas.controls.Color.fromString("#ccf"));
                    break;
            }
        },

        _getAdapterNamePrefix: function () {
            /// <summary>
            /// Should be overridden by implementing adapters to return a nice name for name generation (just prefix).
            /// </summary>
            /// <returns type="String">The prefix to use for any generated names.</returns>

            return "stickynote";
        },

        getControlProperties: function (path, options) {
            /// <summary>
            /// Called to get the object with the list of properties on the root control, or any sub-element of the control.
            /// </summary>
            /// <param name="path" type="Array" elementType="dundas.view.controls.PropertyPathItem" optional="true">(optional) The path to the sub-element 
            /// of this control. Undefined if the root is requested, otherwise an array of plain objects with properties.</param>
            /// <param name="options" type="Object" optional="true">(optional) The options in which to get the control properties. Structure:
            ///     doNotRecord             [type: Boolean, optional: true]             - (optional) True to generate control properties that do not record any adapter state for undo/redo-ability.
            ///     isSimpleMode            [type: Boolean, optional: true]             - (optional) True to get the 'simple' properties for displaying the quick access property editor.
            /// </param>
            /// <returns type="dundas.controls.ObjectDescriptor">An object with the list of properties on the desired element.</returns>

            var objectDescriptor,
                propertyDescriptor,
                elementName;

            // Base path properties.
            if (!path) {
                // Object descriptor.
                objectDescriptor = this._super(path, options);

                // Label text.
                propertyDescriptor = new dundas.StringPropertyDescriptor();
                propertyDescriptor.name = "Stickynote Text";
                propertyDescriptor.id = "stickynoteText";
                propertyDescriptor.category = "GS_PropertyGrid_Category_Common".localize();
                propertyDescriptor.description = "Sample Sticky note control";
                propertyDescriptor.value = this.stickynoteText;
                propertyDescriptor.defaultValue = "Lorem Ipsum";
                propertyDescriptor.section = dundas.controls.PropertyGridSections.Text;

                objectDescriptor.addProperty(propertyDescriptor);

                // Angle.
                propertyDescriptor = new dundas.NumericPropertyDescriptor;
                propertyDescriptor.name = "Angle";
                propertyDescriptor.id = "angle";
                propertyDescriptor.category = "GS_PropertyGrid_Category_Common".localize();
                propertyDescriptor.description = "The angle.";
                propertyDescriptor.value = this.angle;
                propertyDescriptor.defaultValue = -3;
                propertyDescriptor.section = dundas.controls.PropertyGridSections.Look;

                objectDescriptor.addProperty(propertyDescriptor);

                // Background.
                propertyDescriptor = new dundas.PropertyDescriptor();
                propertyDescriptor.name = "Background";
                propertyDescriptor.id = "background";
                propertyDescriptor.category = "GS_PropertyGrid_Category_Common".localize();
                propertyDescriptor.description = "The background";
                propertyDescriptor.value = this.background;
                propertyDescriptor.defaultValue = new dundas.controls.SolidColorBrush(dundas.controls.Color.fromString("#cfc"));
                propertyDescriptor.isNullable = true;
                propertyDescriptor.section = dundas.controls.PropertyGridSections.Look;

                objectDescriptor.addProperty(propertyDescriptor);
            }
           
            return objectDescriptor;
        },

        stringifyControl: function () {
            /// <summary>
            /// Called to instruct this adapter to get a stringified version of the underlying control.
            /// </summary>
            /// <returns type="String">A string representation of the underlying control which can be stored.</returns>
           
            var object = {};

            object.background = this.background;
            object.angle = this.angle;
            object.stickynoteText = this.stickynoteText;

            return JSON.stringify(object);
        },

        parseControl: function (objectString) {
            /// <summary>
            /// Called to instruct the adapter to set the control up based on the stringified version.
            /// </summary>
            /// <param name="objectString" type="String">The stringified version of the underlying control.</param>
            
            var object = JSON.parse(objectString);

            if (this.control == null) {
                this._createControl();
            }

            this.background = Utility.parseItem(object.background);
            this.stickynoteText = object.stickynoteText;
            this.angle = object.angle;
        },

        __properties: {
            "__classType": {
                get: function () {
                    return "mycompany.controls.sample.stickynote.Adapter";
                }
            },

            "stickynoteText": {
                /// <summary>
                /// Gets or sets the text label displayed in the control.
                /// </summary>
                /// <value type="String">The value to display.</value>
                get: function () {
                    return this._stickynoteText;
                },
                set: function (value) {
                    this._stickynoteText = value;
                    if(this._label) {
                        this._label.text(value);
                    }
                },
                notEnumerable: true
            },

            "background": {
                /// <summary>
                /// Gets or sets the background property of the control.
                /// </summary>
                /// <value type="dundas.controls.SolidColorBrush" mayBeNull="true"></value>
                get: function () {
                    return this._background;
                },
                set: function (brush) {
                    this._background = brush;
                    if (this.control) {
                        if (brush) {
                            brush.applyToElement(this.control.get(0), 'background');
                        }
                        else {
                            $(this.container).css({ background: '' });
                        }
                    }
                },
                notEnumerable: true
            },

            "angle": {
                /// <summary>
                /// Gets or sets the angle of the control.
                /// </summary>
                /// <value type="Number" mayBeNull="true">The angle of the control.</value>
                get: function () {
                    return this._angle;
                },
                set: function (value) {
                    this._angle = value;
                    if (this.control) {
                        this.control.css("-o-transform", "rotate(" + value + "deg)");
                        this.control.css("-webkit-transform", "rotate(" + value + "deg)");
                        this.control.css("-moz-transform", "rotate(" + value + "deg)");

                    }
                },
                notEnumerable: true
            }
        }
    });

})(jQuery);